﻿<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

  <!-- Declare output -->
  <xsl:output method="xml" encoding="utf-8" indent="yes" />

  <!-- Declare keys -->
	<xsl:key name="PRODUCT" match="/SHOP/SHOPITEM" use="CODE"/>
	<xsl:key name="VARIANT" match="/SHOP/SHOPITEM/PARAMETERS/PARAMETER" use="CODE"/>

	<!-- Which template we use with root node -->
	<xsl:template match="/SHOP">
	  <DATA Mode="all">
		  <xsl:apply-templates select="SHOPITEM"/>
	  </DATA>
  </xsl:template>
	
  <!-- Shop item template -->
  <xsl:template match="SHOPITEM">
    <!-- Podminka na unikantost -->
    <xsl:if test="generate-id() = generate-id(key('PRODUCT', CODE))">   
      <PRODUCT UniqueID="Krasa-{CODE}-MAIN" _parameterCode="{PARAMETERS/PARAMETER[1]/CODE}">

        <CATALOGUENUMBER>
          <xsl:value-of select="concat('Krasa-',CODE)"/>
        </CATALOGUENUMBER>

        <MANUFACTURERNAME>
          <xsl:value-of select="MANUFACTURER"/>
        </MANUFACTURERNAME>
        
        <xsl:if test="IMGURL != ''">
          <PICTURE>
            <!-- skladani adresy: <xsl:value-of select="concat('http://www.eproton.cz/RemoteImages/', IMGURL)"/> -->
            <xsl:value-of select="IMGURL"/>
          </PICTURE>
        </xsl:if>


        <xsl:if test="VAT = '9'">
          <VATRATE UniqueID="VATRATE_REDUCED" />
        </xsl:if>
        <xsl:if test="VAT = '19' or VAT = '15'">
          <VATRATE UniqueID="VATRATE_STANDARD" />
        </xsl:if>

        <!-- Doba dodani - Importovat hodnotu AVAILABILITY -->
        <DELIVERYTIME>
          <xsl:value-of select="AVAILABILITY"/>
        </DELIVERYTIME>
		  <xsl:choose>
			  <xsl:when test="(count(PARAMETERS/PARAMETER)>0) and (PARAMETERS/PARAMETER[1]/CODE != CODE)">
				  <SALEFORBIDDEN>1</SALEFORBIDDEN>
			  </xsl:when>
			  <xsl:otherwise>
				  <SALEFORBIDDEN>0</SALEFORBIDDEN>
			  </xsl:otherwise>
		  </xsl:choose>

		  <NEW>
          <xsl:value-of select="ADD_DESCRIPTION/FLAG/@news"/>
		  </NEW>

		  <TIP>
			  <xsl:value-of select="ADD_DESCRIPTION/FLAG/@recommended" />
		  </TIP>
		  <SALE>
			  <xsl:value-of select="ADD_DESCRIPTION/FLAG/@sale" />
		  </SALE>

		  <ACTION>
          <xsl:value-of select="ADD_DESCRIPTION/FLAG/@action"/>
        </ACTION>

		  <SUPPLIER UniqueID="Krasa" />
	  </PRODUCT>
	  <xsl:apply-templates select="PARAMETERS/PARAMETER"/>
  </xsl:if>
  </xsl:template>

	<xsl:template match="PARAMETERS/PARAMETER">
		<!-- 
		zajištění unikátnosti:
			nový výrobek bude vložen jen v případě, že jeho kód není použit jako kód jiného hlavního výrobku 
			ani není použitý mezi jinými variantami
		-->
		<xsl:if test="count(key('PRODUCT', CODE)) = 0 and  generate-id() = generate-id(key('VARIANT', CODE))">
			<PRODUCT UniqueID="Krasa-{CODE}" _linkedto="Krasa-{../../CODE}-MAIN">
				<CATALOGUENUMBER>
					<xsl:value-of select="CODE"/>
				</CATALOGUENUMBER>

				<MANUFACTURERNAME>
					<xsl:value-of select="../../MANUFACTURER"/>
				</MANUFACTURERNAME>

				<xsl:if test="../../IMGURL != ''">
					<PICTURE>
						<xsl:value-of select="../../IMGURL"/>
					</PICTURE>
				</xsl:if>
				<HIDDEN>1</HIDDEN>

				<xsl:if test="../../VAT = '9'">
					<VATRATE UniqueID="VATRATE_REDUCED" />
				</xsl:if>
				<xsl:if test="../../VAT = '19' or ../../VAT = '15'">
					<VATRATE UniqueID="VATRATE_STANDARD" />
				</xsl:if>

				<!-- Doba dodani - Importovat hodnotu AVAILABILITY -->
				<DELIVERYTIME>
					<xsl:choose>
						<xsl:when test="AVAILABILITY='0'">
							<xsl:value-of select="../../AVAILABILITY"/>
						</xsl:when>
						<xsl:otherwise>
							1
						</xsl:otherwise>
					</xsl:choose>
				</DELIVERYTIME>


				<NEW>
					<xsl:value-of select="FLAG/@news" />
				</NEW>

				<TIP>
					<xsl:value-of select="FLAG/@recommended" />
				</TIP>
				<SALE>
					<xsl:value-of select="FLAG/@sale" />
				</SALE>

				<ACTION>
					<xsl:value-of select="FLAG/@action" />
				</ACTION>

				<SIGN1>
					<xsl:value-of select="ADD/@tester" />
				</SIGN1>
				<SIGN2>
					<xsl:value-of select="ADD/@sada" />
				</SIGN2>
				<SIGN3>
					<xsl:value-of select="ADD/@edice" />
				</SIGN3>
				<SUPPLIER UniqueID="Krasa" />
			</PRODUCT>
		</xsl:if>
	</xsl:template>
  
</xsl:stylesheet>

