<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:param name="BuyingPriceList"/>
<xsl:param name="ProfitMargin" />
<xsl:output method="xml" encoding="utf-8" indent="yes" />
<xsl:decimal-format decimal-separator="."/>
	<xsl:key name="product" match="/Pocitace_Business_Marketplace/record"
			 use="MATNR"/>

<xsl:template match="/Pocitace_Business_Marketplace">
	<DATA Mode="all">
		<xsl:apply-templates select="*"/>
	</DATA>
</xsl:template>
	
<xsl:template match="record">
	<xsl:if test="generate-id() = generate-id(key('product', MATNR))">
		<PRODUCT UniqueID="{EAN11}">

      <CATALOGUENUMBER>
        <xsl:value-of select="MATNR"/>
      </CATALOGUENUMBER>

      <MANUFACTURERNAME>
        <xsl:value-of select="ZNACKA" />
      </MANUFACTURERNAME>

      <!-- pocet kusu na sklade -->
      <xsl:choose>
        <xsl:when test="AVAILIBILITY = 0">
          <AMOUNTINSTORE>0</AMOUNTINSTORE>
        </xsl:when>
        <xsl:otherwise>
          <AMOUNTINSTORE>1</AMOUNTINSTORE>
        </xsl:otherwise>
      </xsl:choose>
      
      <!-- TIP -->
      <xsl:choose>
        <xsl:when test="AVAILIBILITY = 0">
          <TIP>0</TIP>
        </xsl:when>
        <xsl:otherwise>
          <TIP>1</TIP>
        </xsl:otherwise>
      </xsl:choose>      
      
      <THUMBNAIL>
        <xsl:value-of select="PATH_SIM"/>
      </THUMBNAIL>
      
      <PICTURE>
        <xsl:value-of select="PATH_LIM"/>
      </PICTURE>

      <SALEFORBIDDEN>0</SALEFORBIDDEN>
      <KIND>0</KIND>

      <MEASUREMENTUNIT>
        <xsl:value-of select="MEINH" />
      </MEASUREMENTUNIT>

      <SALE>
        <xsl:if test="ZVYP = 'X'">1</xsl:if>
        <xsl:if test="ZVYP != 'X'">0</xsl:if>
      </SALE>

      <NEW>
        <xsl:if test="ZNOV = 'X'">1</xsl:if>
        <xsl:if test="ZNOV != 'X'">0</xsl:if>
      </NEW>
      
      <ACTION>
        <xsl:if test="ZAKCE='X'">1</xsl:if>
        <xsl:if test="ZAKCE != 'X'">0</xsl:if>
      </ACTION>      
      
      <!-- ceny a s tim souvisejici-->
      
      <xsl:if test="DPH = '19%'">
        <VATRATE UniqueID="VATRATE_STANDARD"/>
      </xsl:if>
      <xsl:if test="DPH = '5%'">
        <VATRATE UniqueID="VATRATE_REDUCED"/>
      </xsl:if>

      <SettlingExtraPayValue>
        <xsl:value-of select="number(translate(translate(PRICE_PHE, ',', '.'), ' ', ''))"/>
      </SettlingExtraPayValue>

      <!-- pokud neni akce, bereme VO cenu -->
      <xsl:if test="ZAKCE != 'X'">
        <xsl:choose>
          <xsl:when test="$ProfitMargin = '0'">
            <PRICEA>
              <!-- nakupni cena - v nastaveni importu musi byt nastaveno, ze dealersky cenik A je nakupni cenik -->
              <xsl:value-of select="number(translate(translate(PRICE_VO, ',', '.'), ' ', ''))"/>
            </PRICEA>
          </xsl:when>
          <xsl:otherwise>
            <PRICEA>
              <xsl:value-of select="(1.0 + (number(translate(translate($ProfitMargin, ',', '.'), ' ', '')) div 100)) * number(translate(translate(PRICE_VO, ',', '.'), ' ', ''))"/>
            </PRICEA>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:if>

      <!-- pokud je akce, bereme akcni cenu -->
      <xsl:if test="ZAKCE = 'X'">
        <xsl:choose>
          <xsl:when test="$ProfitMargin = '0'">
            <PRICEA>
              <!-- nakupni cena - v nastaveni importu musi byt nastaveno, ze dealersky cenik A je nakupni cenik -->
              <xsl:value-of select="number(translate(translate(PRICE, ',', '.'), ' ', ''))"/>
            </PRICEA>
          </xsl:when>
          <xsl:otherwise>
            <PRICEA>
              <xsl:value-of select="(1.0 + (number(translate(translate($ProfitMargin, ',', '.'), ' ', '')) div 100)) * number(translate(translate(PRICE, ',', '.'), ' ', ''))"/>
            </PRICEA>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:if>      
      
      <xsl:if test="$BuyingPriceList != ''">
        <BUYINGPRICELIST UniqueID="{$BuyingPriceList}" />
      </xsl:if>

      <SUPPLIER UniqueID="Pocitace" />

    </PRODUCT>
	</xsl:if>
</xsl:template>
</xsl:stylesheet>

